#!/bin/bash

PATHPREFIX=`dirname $0`
CURDIR=`pwd`
TESTNAME=asterisk_180SDP

INCOMINGPORT=$(shuf -i10001-65000 -n1)
OUTGOINGPORT=$(( $INCOMINGPORT - 1 ))

# Start TCPDUMP
tcpdump -pni any -w /tmp/alltraffic.pcap &
tcpdumpPid=$!

sipp kamailio -sf $PATHPREFIX/incoming/sipp_register.xml -inf "$PATHPREFIX/incoming/sip-credentials.csv" -m 1 -p $INCOMINGPORT -timeout 10s \
     -trace_msg -message_file /tmp/${TESTNAME}-${USER}-REGISTER_messages.log \
     -trace_err -error_file /tmp/${TESTNAME}-${USER}-REGISTER_error.log \
     -trace_logs -log_file /tmp/${TESTNAME}-${USER}-REGISTER_logs.log \
     -trace_screen -screen_file /tmp/${TESTNAME}-${USER}-REGISTER_report.log &
wait $!
if [ $? -gt 0 ]; then
	echo "Unable to register Client"
	exit 1
fi

sleep 1

sipp kamailio -sf $PATHPREFIX/incoming/sipp_accept.xml -l 1 -m 1 -p $INCOMINGPORT -timeout 60s \
     -trace_msg -message_file /tmp/${TESTNAME}-${USER}-IN_messages.log \
     -trace_err -error_file /tmp/${TESTNAME}-${USER}-IN_error.log \
     -trace_logs -log_file /tmp/${TESTNAME}-${USER}-IN_logs.log \
     -trace_screen -screen_file /tmp/${TESTNAME}-${USER}-IN_report.log &
incomingPid=$!

sipp kamailio -sf "$PATHPREFIX/outgoing/sipp_outgoing.xml" -inf "$PATHPREFIX/outgoing/sip-credentials.csv" -m 1 -p $OUTGOINGPORT -timeout 60s \
     -trace_msg -message_file /tmp/${TESTNAME}-${USER}-OUT_messages.log \
     -trace_err -error_file /tmp/${TESTNAME}-${USER}-OUT_error.log \
     -trace_logs -log_file /tmp/${TESTNAME}-${USER}-OUT_logs.log \
     -trace_screen -screen_file /tmp/${TESTNAME}-${USER}-OUT_report.log &
outgoingPid=$!

wait $incomingPid
incomingResult=$?
wait $outgoingPid
outgoingResult=$?

kill $tcpdumpPid
echo "Traffic log is in /tmp/alltraffic.pcap"

echo "Return Code of Incoming was $incomingResult"
echo "Return Code of Outgoing was $outgoingResult"

if [ $incomingResult -gt $outgoingResult ]; then
    exit $incomingResult
else
    exit $outgoingResult
fi
